build_product: Build a SQL product

Description Usage Arguments Value

View source: R/modelc.r

Description

Build a SQL product

Usage

1
build_product(lhs, rhs)

Arguments

lhs

A character string representing the left hand side of the multiplication

rhs

A character string representing the right hand side of the multiplication

Value

A character string representing a valid SQL product term


team-sparkfish/modelc documentation built on June 21, 2020, 10:57 a.m.