Learn R Programming

modelc (version 1.0.0.0)

build_product: Build a SQL product

Description

Build a SQL product

Usage

build_product(lhs, rhs)

Arguments

lhs

A character string representing the left hand side of the multiplication

rhs

A character string representing the right hand side of the multiplication

Value

A character string representing a valid SQL product term