powered by
Build a SQL product
build_product(lhs, rhs)
A character string representing the left hand side of the multiplication
A character string representing the right hand side of the multiplication
A character string representing a valid SQL product term